import 'dart:math';
import 'package:animated_check/animated_check.dart';
import 'package:confetti/confetti.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_assesment/MyHomePage.dart';
import 'package:flutter_assesment/utils/config.dart';
import 'package:simple_ripple_animation/simple_ripple_animation.dart';
class Celibration extends StatefulWidget {
  const Celibration({Key? key}) : super(key: key);

  @override
  _CelibrationState createState() => _CelibrationState();
}

class _CelibrationState extends State<Celibration>  with TickerProviderStateMixin {


  late double _scale;
  late AnimationController _controller;


  late AnimationController _animationController;
  late Animation<double> _animation;


  late ConfettiController _confettiController;
  @override
  void dispose() {
    super.dispose();
    _controller.dispose();
    _confettiController.dispose();
    _animationController.dispose();
  }


  @override
  void initState() {

    _animationController =
        AnimationController(vsync: this, duration: Duration(seconds: 1));

    _animation = new Tween<double>(begin: 0, end: 1).animate(
        new CurvedAnimation(
            parent: _animationController, curve: Curves.easeInOutCirc));

    _animationController.forward;
    _confettiController = ConfettiController(duration: Duration(seconds: 4));
    _confettiController.play();
    _controller = AnimationController(
      vsync: this,
      duration: Duration(milliseconds: 100,),lowerBound: 0.0,upperBound: 0.1,)..addListener(() {
      setState(() {});
    });
    super.initState();
  }

  void _tapDown(TapDownDetails detais){
    _controller.forward();
  }
  void _tapUp(TapUpDetails detais){
    _controller.reverse();

    Future.delayed(const Duration(milliseconds: 100), () {


      Navigator.push(context, MaterialPageRoute(builder: (context) => MyHomePage()));
    });
  }
  @override
  Widget build(BuildContext context) {
    _scale = 1- _controller.value;
    return WillPopScope(
      onWillPop: () async {
       Navigator.push(context, MaterialPageRoute(builder: (context) => MyHomePage()));
        return true;
      },
      child: Scaffold(body: Stack(children: [


        Positioned(
            height: MediaQuery.of(context).size.height * 0.5 +250,
            left: MediaQuery.of(context).size.width * 0.5,
            child: RippleAnimation(
                repeat: true,
                color: Color(0xff11cd99),
                minRadius: 90,
                ripplesCount: 6,
                child: Container()
            ),),


        Container(
          child: CustomPaint(
            child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                SizedBox(height: MediaQuery.of(context).size.height*0.5,),
                Text(Config.supportCompleted,style: TextStyle(fontWeight: FontWeight.bold,color: Color(0xff11cd99),fontSize: 25),),
                SizedBox(height: 70,),
                GestureDetector(
                  /* onTap: (){
                      Navigator.pop(context);
                    },*/
                  onTapDown: _tapDown,
                  onTapUp: _tapUp,
                  child: Transform.scale(
                    scale: _scale,
                    child: Container(
                      alignment: Alignment.center,
                      width: MediaQuery.of(context).size.width,
                      margin: const EdgeInsets.fromLTRB(30.0,0.0,30.0,0.0),
                      height: 55,
                      decoration: BoxDecoration(
                        gradient: LinearGradient(
                            colors: [const Color(0xff5488c9),const Color(0xff255794)],
                            begin: const FractionalOffset(0.0, 0.0),
                            end: const FractionalOffset(1.0, 0.0),
                            stops: [0.0,1.0],
                            tileMode: TileMode.clamp),
                        border: Border.all(width: 5,color: Color(0xffe5ebf2)),
                        borderRadius: BorderRadius.all(Radius.circular(50.0)),
                      ),
                      child: Text(Config.supportDone,style: TextStyle(color: Colors.white,fontWeight: FontWeight.bold,fontSize: 17),),
                    ),
                  ),
                )
              ],),
          ),
        ),

        Positioned(
            height: MediaQuery.of(context).size.height * 0.5 +250,
            left: MediaQuery.of(context).size.width * 0.5 - 50,
            child: Image.asset("assets/images/checktwo.png",width: 100,height: 100,)),
        Align(
          alignment: Alignment.topCenter,
          child: ConfettiWidget(
            confettiController: _confettiController,
            colors: [
              Colors.red,
              Colors.blue,
              Colors.orange,
              Colors.purple,
              Colors.lightBlue,
            ],
            blastDirectionality: BlastDirectionality.explosive,
            shouldLoop: false,
            emissionFrequency: 0.05,
            numberOfParticles: 3,
            gravity: 0.2,
            maxBlastForce: 2,
            minBlastForce: 1,
            particleDrag: 0.1,
            createParticlePath: drawStar,
          ),
        ),
        Align(
          alignment: Alignment.topCenter,
          child: ConfettiWidget(
            confettiController: _confettiController,
            colors: [
              Colors.red,
              Colors.blue,
              Colors.orange,
              Colors.purple,
              Colors.lightBlue,
            ],
            blastDirectionality: BlastDirectionality.explosive,
            shouldLoop: false,
            emissionFrequency: 0.1,
            numberOfParticles: 5,
            gravity: 0.2,
            maxBlastForce: 2,
            minBlastForce: 1,
            particleDrag: 0.1,
          ),
        ),
      ],)),
    );
  }
}

/// A custom Path to paint stars.
Path drawStar(Size size) {
  // Method to convert degree to radians
  double degToRad(double deg) => deg * (pi / 180.0);

  const numberOfPoints = 5;
  final halfWidth = size.width / 2;
  final externalRadius = halfWidth;
  final internalRadius = halfWidth / 2.5;
  final degreesPerStep = degToRad(360 / numberOfPoints);
  final halfDegreesPerStep = degreesPerStep / 2;
  final path = Path();
  final fullAngle = degToRad(360);
  path.moveTo(size.width, halfWidth);

  for (double step = 0; step < fullAngle; step += degreesPerStep) {
    path.lineTo(halfWidth + externalRadius * cos(step),
        halfWidth + externalRadius * sin(step));
    path.lineTo(halfWidth + internalRadius * cos(step + halfDegreesPerStep),
        halfWidth + internalRadius * sin(step + halfDegreesPerStep));
  }
  path.close();
  return path;
}
